# Overview


[![PyPI Downloads](https://static.pepy.tech/badge/pbi-core)](https://pepy.tech/projects/pbi-core)
![Python](https://img.shields.io/badge/python-3.11-blue.svg)
[![Coverage Status](https://coveralls.io/repos/github/douglassimonsen/pbi_core/badge.svg?branch=main)](https://coveralls.io/github/douglassimonsen/pbi_core?branch=main)
![Repo Size](https://img.shields.io/github/repo-size/douglassimonsen/pbi_core)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_core.svg?type=shield&issueType=license)](https://app.fossa.com/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_core?ref=badge_shield&issueType=license)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_core.svg?type=shield&issueType=security)](https://app.fossa.com/projects/git%2Bgithub.com%2Fdouglassimonsen%2Fpbi_core?ref=badge_shield&issueType=security)

`pbi_core` is a Python library designed to facilitate the creation and management of Power BI datasets. It provides a structured way to define datasets, tables, and relationships, making it easier to work with Power BI's data models.

Read the [documentation](https://douglassimonsen.github.io/pbi_core/) for more information.
